"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SpryngtimeOpenAI = void 0;
const { OpenAIClient, AzureKeyCredential } = require("@azure/openai");
const { SpryngtimeAnalyticsSdk } = require("spryngtime-analytics-sdk");
class SpryngtimeOpenAI extends OpenAIClient {
    constructor() {
        super(process.env.AZURE_OPENAI_ENDPOINT, new AzureKeyCredential(process.env.AZURE_OPENAI_API_KEY));
        this.SpryngtimeApiKey = process.env.SPRYNGTIME_API_KEY || "";
        this.SpryngtimeAnalyticsSdk = new SpryngtimeAnalyticsSdk({
            apiKey: this.SpryngtimeApiKey
        });
        // Store the reference to the original chat.completions.create method
        this.originalChatCompletionsCreate = this.getChatCompletions.bind(this);
        // Override the chat.completions.create method
        this.getChatCompletions = (deploymentId, messages, params) => __awaiter(this, void 0, void 0, function* () {
            const startTime = Date.now();
            // Use the stored reference to call the original method
            const result = yield this.originalChatCompletionsCreate(deploymentId, messages, params);
            const latency = Date.now() - startTime;
            try {
                if (!params.stream) {
                    this.SpryngtimeAnalyticsSdk.usageTracking.trackUsage({
                        key: params.user,
                        query: messages[0].content,
                        openAiResponse: result,
                        conversationId: params.conversationId,
                        customProperties: params.customProperties,
                        tags: params.tags,
                        latency: latency
                    });
                }
            }
            catch (error) {
                console.error('Error tracking analytics:', error);
                // Handle the error appropriately
            }
            finally {
                // Code here will run regardless of the try / catch outcome
                return result;
            }
            return result;
        });
    }
}
exports.SpryngtimeOpenAI = SpryngtimeOpenAI;
