const { OpenAIClient, AzureKeyCredential } = require("@azure/openai");

const {SpryngtimeAnalyticsSdk} = require("spryngtime-analytics-sdk");


export class SpryngtimeOpenAI extends OpenAIClient {
    SpryngtimeApiKey: string;
    SpryngtimeAnalyticsSdk: typeof SpryngtimeAnalyticsSdk;

    originalChatCompletionsCreate: (params: any, messages: any, params1: any) => Promise<any>;

    constructor() {
        super(process.env.AZURE_OPENAI_ENDPOINT, new AzureKeyCredential(process.env.AZURE_OPENAI_API_KEY));

        this.SpryngtimeApiKey = process.env.SPRYNGTIME_API_KEY || "";
        this.SpryngtimeAnalyticsSdk = new SpryngtimeAnalyticsSdk({
            apiKey: this.SpryngtimeApiKey
        });
        // Store the reference to the original chat.completions.create method
        this.originalChatCompletionsCreate = this.getChatCompletions.bind(this);

        // Override the chat.completions.create method
        this.getChatCompletions = async (deploymentId: any, messages:any, params:any): Promise<any> => {
            const startTime = Date.now();

            // Use the stored reference to call the original method
            const result = await this.originalChatCompletionsCreate(deploymentId, messages, params);

            const latency = Date.now() - startTime;
            try {
                if (!params.stream) {
                    this.SpryngtimeAnalyticsSdk.usageTracking.trackUsage({
                        key: params.user,
                        query: messages[0].content,
                        openAiResponse: result,
                        conversationId: params.conversationId,
                        customProperties: params.customProperties,
                        tags: params.tags,
                        latency: latency
                    });
                }
            } catch (error) {
                console.error('Error tracking analytics:', error);
                // Handle the error appropriately
            } finally {
                // Code here will run regardless of the try / catch outcome
                return result;
            }

            return result;
        };
    }
}

